import React, { useState, useEffect } from 'react'
import { Select, Spin, Table, Button, Form, Input, Divider, Modal,Popconfirm } from 'antd'
import NavLink from 'umi/navlink'
import moment from 'moment'
import { fetch, apis, fetchList } from '@/utils/request'
import { exportExcel } from '@/utils/utils'
import IntegralRecord from '../customerlist/components/integralRecord'

const getPersonList = fetchList(apis.person.getPersonList)
const exportPersonList = fetch(apis.person.export)

const Condition = Form.create()(props => {
  const handleSubmit = e => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err && props.onSearch) {
        props.onSearch(values)
      }
    });
  }

  const handleReset = e => {
    props.form.resetFields()
    if (props.onReset) {
      props.onReset(props.form.getFieldsValue())
    }
  }

  const { getFieldDecorator } = props.form

  return (
    <Form layout="inline" onSubmit={handleSubmit}>
      <div style={{ display: 'flex', width: '100%' }}>
        <div style={{ flex: 'none', maxWidth: 'calc(100% - 180px)' }}>
            <Form.Item label="姓名">
            {
              getFieldDecorator('name')(<Input placeholder="姓名" />)
            }
            </Form.Item>
            <Form.Item label="手机号">
            {
              getFieldDecorator('phone')(<Input placeholder="手机号" />)
            }
            </Form.Item>
            <Form.Item label="推荐人">
            {
              getFieldDecorator('recommended')(<Input placeholder="推荐人" />)
            }
            </Form.Item>
        </div>
        <div style={{ flex: 'none', width: '180px' }}>
          <Form.Item>
            <Button type="primary" htmlType="submit">搜索</Button>
          </Form.Item>
          <Form.Item>
            <Button onClick={handleReset}>重置</Button>
          </Form.Item>
        </div>
      </div>
    </Form>
  )
})

export default props => {
  const [loading, setLoading] = useState(false)
  const [listData, setListData] = useState([])
  const [pagination, setPagination] = useState({})
  const [queryParams, setQueryParams] = useState({ pageNum: 1, pageSize: 10 })
  const [showPoints, setShowPoints] = useState({visible: false, customerId: ''})

  const handleSearch = vals => {
    setQueryParams({
      ...queryParams,
      ...vals,
      pageNum: 1,
    })
  }

  const handlePageChange = (pageNum, pageSize) => {
    setQueryParams({
      ...queryParams,      
      pageNum,
      pageSize,
    })
  }

  const handleExport = () => {
    exportPersonList({params: queryParams}).then(res => {
      exportExcel(res, '会员列表')
    })
  }

  useEffect(() => {
    setLoading(true)
    getPersonList(queryParams).then(res => {
      const [list, pageInfo] = res || {}
      setListData(list)
      setPagination(pageInfo)
      setLoading(false)
    }).catch(() => setLoading(false))
  }, [queryParams])

  return (
    <div>
      <Condition onSearch={handleSearch} onReset={handleSearch} />
      <div style={{margin: '24px 0'}}><Button type="" onClick={handleExport}>导出</Button></div>
      <Table dataSource={listData} loading={loading} pagination={{...pagination, onChange: handlePageChange}} rowKey="personId">
        <Table.Column
          title="头像"
          dataIndex="avatarurl"
          key="avatarurl"
          render={t => <img src={t} alt="" style={{width: '64px', height: '64px'}} />}
        />
        <Table.Column title="姓名" dataIndex="nickname" key="nickname" render={(t,row) => row.name || t} />
        <Table.Column title="电话" dataIndex="phone" key="phone" render={(t, row) => {
          const phone = row.tel || t || ''
          return phone.replace(/(\d{3})\d*(\d{4})/,'$1****$2')
        }} />
        <Table.Column title="性别" dataIndex="gender" key="gender" render={(t,row) => {
          const sex = row.sex || t
          if (!sex) return ''

          return sex == 1 ? '男' : '女'
        }} />
        <Table.Column title="推荐人" dataIndex="sharePersonName" key="sharePersonName" />
        {/* <Table.Column title="总积分" dataIndex="points" key="points" /> */}
        <Table.Column title="创建时间" dataIndex="createDate" key="createDate" render={t => moment(t).format('YYYY-MM-DD HH:mm')} />
        {/* <Table.Column
          title="操作"
          key="action"
          render={(_, row) => {
            return (
              <>
                <Button type="link" onClick={() => setShowPoints({visible: true, customerId: row.personId})}>积分明细</Button>
              </>
            )
          }}
        /> */}
      </Table>
      <IntegralRecord visibleData={showPoints} onCancel={() => setShowPoints({visible: false, customerId: ''})} />
    </div>
  )
}
