import React, { useEffect, useState } from 'react'
import { Button, Modal, Table, Form, InputNumber, Input, notification } from 'antd'
import moment from 'moment'
import { fetchList, fetch, apis } from '@/utils/request'

const getPointsRules = fetchList(apis.integralMall.tdPointsRules)
const getPointsRecords = fetch(apis.customer.taPointsRecords)
const savePointsRecords = fetch(apis.customer.savePointsRecords)

const otherRules = [
  {code: 'goods', ruleName: '商品兑换'}
]

const layout = {
  labelCol: { span: 4 },
  wrapperCol: { span: 16 },
};

const isNvl = x => x === undefined || x === null || x === ''

export default props => {
  const [loading, setLoading] = useState(false)
  const [showModal, setShowModal] = useState(false)
  const [pointsRules, setPointsRules] = useState([])
  const [listData, setListData] = useState([])
  const [queryParams, setQueryParams] = useState({pageNumber: 1, pageSize: 10})
  const [pagination, setPagination] = useState()
  
  const [pointsAmount, setPointsAmount] = useState()
  const [changeType, setChangeType] = useState(false)

  const getChangeName = typ => {
    const target = pointsRules.filter(x => x.code === typ)[0]

    return target ? target.ruleName : typ
  }

  const handleChange = (page) => {
    setQueryParams({
      ...queryParams,
      pageNumber: page.current
    })
  }

  const handleSubmit = () => {
    if (isNvl(pointsAmount) || isNvl(changeType)) {
      notification.warn({message: '请填写积分或者说明'})
      return
    }

    setLoading(true)
    savePointsRecords({data: { personId: props.userData.personId, pointsAmount, changeType }}).then(res => {
      setQueryParams({
        ...queryParams,
        pageNumber: 1
      })
      toggleModal()

      notification.success({message: '积分维护成功'})
      setLoading(false)
    }).catch(e => console.error(e) || setLoading(false) || toggleModal())
  }

  const toggleModal = () => {
    setShowModal(!showModal)
    setPointsAmount()
    setChangeType()
  }

  useEffect(() => {
    setLoading(true)

    const params = {
      urlData: {id: props.userData.personId},
      params: queryParams
    }

    getPointsRecords(params).then(res => {
      const { records = [], current, total, pageSize } = res.result
      setListData(records)
      setPagination({current, total, pageSize})
      setLoading(false)
    }).catch(e => console.error(e) || setLoading(false))
  }, [queryParams, props.userData])

  useEffect(() => {
    getPointsRules({pageNum: 1, pageSize: 100}).then(res => {
      const [list] = res
      setPointsRules((list || []).concat(otherRules))
    })
  }, [])

  return (
    <div>
      <div style={{margin: '16px 0'}}>
        <Button icon="plus" onClick={toggleModal}>积分维护</Button>
      </div>
      <Table loading={loading} dataSource={listData} pagination={pagination} onChange={handleChange} rowKey="pointsRecordId">
        <Table.Column title="类型" dataIndex="changeType" key="changeType" render={t => getChangeName(t)} />
        <Table.Column title="积分" dataIndex="pointsAmount" key="pointsAmount" render={t => getChangeName(t)} />
        <Table.Column title="日期" dataIndex="createDate" key="createDate" render={t => moment(t).format('YYYY-MM-DD HH:mm')} />
      </Table>
      <Modal visible={showModal} title="积分维护" onOk={handleSubmit} onCancel={toggleModal}>
        <Form {...layout}>
          <Form.Item label="积分" required>
            <InputNumber placeholder="负值代表消费积分" step={1} value={pointsAmount} style={{width: '100%'}} onChange={e => setPointsAmount(e - 0)}></InputNumber>
          </Form.Item>
          <Form.Item label="说明" required>
            <Input placeholder="填写消费说明" value={changeType} onChange={e => setChangeType(e.target.value)}></Input>
          </Form.Item>
        </Form>
      </Modal>
    </div>
  )
}
